@@ -897,7 +897,7 @@ copy_files_to_folder (GthBrowser *browser,
 			  data);
 	gth_browser_exec_task (browser, task, FALSE);
 
-
+	g_object_unref (task);
 	g_object_unref (file_source);
 }
 
@@ -929,7 +929,7 @@ copy_to_folder_dialog (GthBrowser *browser,
 		g_free (start_uri);
 		start_uri = g_strdup (get_home_uri ());
 	}
-	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (dialog), start_uri);
+	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (dialog), start_uri);
 	g_free(start_uri);
 
 	history = _g_settings_get_string_list (settings, PREF_FILE_MANAGER_COPY_HISTORY);
